@@ -2331,8 +2331,8 @@ enum
 };
 
 /* Define CC and CFLAGS which were used to build this version of GMP */
-#define __GMP_CC "cc"
-#define __GMP_CFLAGS "-Os -pipe -fno-plt -march=x86-64 -fstack-clash-protection -fcf-protection -flto=auto"
+#define __GMP_CC "gcc"
+#define __GMP_CFLAGS "-march=x86-64-v4 -O3 -pipe -fno-plt -fexceptions -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security -fstack-clash-protection -fcf-protection -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -mpclmul -g -ffile-prefix-map=/startdir/src=/usr/src/debug/gmp -flto=auto -falign-functions=32"
 
 /* Major version number is the value of __GNU_MP__ too, above. */
 #define __GNU_MP_VERSION            6
